summaryrefslogtreecommitdiffstats
path: root/src/audio_core/renderer/nodes/node_states.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/audio_core/renderer/nodes/node_states.h')
-rw-r--r--src/audio_core/renderer/nodes/node_states.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/audio_core/renderer/nodes/node_states.h b/src/audio_core/renderer/nodes/node_states.h
index a1e0958a2..94b1d1254 100644
--- a/src/audio_core/renderer/nodes/node_states.h
+++ b/src/audio_core/renderer/nodes/node_states.h
@@ -56,7 +56,7 @@ class NodeStates {
*
* @return The current stack position.
*/
- u32 Count() {
+ u32 Count() const {
return pos;
}
@@ -83,7 +83,7 @@ class NodeStates {
*
* @return The node on the top of the stack.
*/
- u32 top() {
+ u32 top() const {
return stack[pos - 1];
}
@@ -112,11 +112,11 @@ public:
/**
* Initialize the node states.
*
* @param buffer - The workbuffer to use. Unused.
* @param node_buffer_size - The size of the workbuffer. Unused.
* @param count - The number of nodes in the graph.
*/
- void Initialize(std::span<u8> nodes, u64 node_buffer_size, u32 count);
+ void Initialize(std::span<u8> buffer_, u64 node_buffer_size, u32 count);
/**
* Sort the graph. Only calls DepthFirstSearch.
@@ -112,11 +112,11 @@ public:
* Initialize the node states.
*
- * @param buffer - The workbuffer to use. Unused.
+ * @param buffer_ - The workbuffer to use. Unused.
* @param node_buffer_size - The size of the workbuffer. Unused.
* @param count - The number of nodes in the graph.